==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionMenuBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
/**
 * @hidden
 */
export let ToolActionMenuBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionMenuBaseDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionMenuBaseDescriptionMetadata.a == null) {
                ToolActionMenuBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionMenuBaseDescriptionMetadata.c(ToolActionMenuBaseDescriptionMetadata.a);
            }
            if (a.j(ToolActionMenuBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionMenuBaseDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("Actions", "Collection:ToolAction:ToolActionCollection:ToolAction");
        }
        static d(a) {
            ToolActionMenuBaseDescriptionMetadata.b(a);
            a.z("ToolActionMenuBase", ToolActionMenuBaseDescriptionMetadata.a);
        }
    }
    ToolActionMenuBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionMenuBaseDescriptionMetadata, 'ToolActionMenuBaseDescriptionMetadata');
    ToolActionMenuBaseDescriptionMetadata.a = null;
    return ToolActionMenuBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionMenuBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
/**
 * @hidden
 */
export let ToolActionMenuBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionMenuBaseDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionMenuBaseDescriptionMetadata.a == null) {
                ToolActionMenuBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionMenuBaseDescriptionMetadata.c(ToolActionMenuBaseDescriptionMetadata.a);
            }
            if (a.k(ToolActionMenuBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionMenuBaseDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("Actions", "Collection:ToolAction:ToolActionCollection:ToolAction");
        }
        static d(a) {
            ToolActionMenuBaseDescriptionMetadata.b(a);
            a.ab("ToolActionMenuBase", ToolActionMenuBaseDescriptionMetadata.a);
        }
    }
    ToolActionMenuBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionMenuBaseDescriptionMetadata, 'ToolActionMenuBaseDescriptionMetadata');
    ToolActionMenuBaseDescriptionMetadata.a = null;
    return ToolActionMenuBaseDescriptionMetadata;
})();
